@@ -1,8 +1,5 @@
 import os
 
-from django.conf import settings
-from django.urls import reverse
-
 from jwt import decode as jwt_decode, DecodeError, ExpiredSignatureError, get_unverified_header
 from social_core.backends.azuread_b2c import AzureADB2COAuth2
 from social_core.backends.azuread_tenant import AzureADTenantOAuth2
@@ -42,16 +39,3 @@ class UNICEFAzureADB2COAuth2(AzureADB2COAuth2):
     """UNICEF Azure ADB2C Custom Backend"""
 
     name = 'unicef-azuread-b2c-oauth2'
-    BASE_URL = 'https://{tenant_name}.b2clogin.com/{tenant_id}'
-
-    @property
-    def base_url(self):
-        return self.BASE_URL.format(tenant_name=self.tenant_name, tenant_id=self.tenant_id)
-
-    @property
-    def tenant_name(self):
-        return self.setting('TENANT_NAME', 'unicef')
-
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.redirect_uri = settings.HOST + reverse('social:complete', kwargs={'backend': 'unicef-azuread-b2c-oauth2'})
