@@ -1,6 +1,6 @@
 import os
 
-from django.conf import settings
+from .utils import get_setting
 
 AZURE_CLIENT_ID = os.environ.get('AZURE_CLIENT_ID', '')
 AZURE_CLIENT_SECRET = os.environ.get('AZURE_CLIENT_SECRET', '')
@@ -17,12 +17,10 @@ AZURE_GRAPH_API_BASE_URL = 'https://graph.microsoft.com'
 AZURE_GRAPH_API_VERSION = 'v1.0'
 AZURE_GRAPH_API_PAGE_SIZE = 300
 
-AZURE_LOGOUT_BASE_URL = getattr(settings, 'SOCIAL_AUTH_TENANT_B2C_URL', getattr(
-    settings, 'TENANT_B2C_URL', os.environ.get('AZURE_LOGOUT_BASE_URL', 'login.microsoftonline.com')))
-
-AZURE_POLICY = getattr(
-    settings, 'SOCIAL_AUTH_POLICY', getattr(settings, 'TENANT_POLICY', ''))
-
-AZURE_TENANT_ID = getattr(settings, 'SOCIAL_AUTH_TENANT_ID', getattr(settings, 'TENANT_ID', '-'))
+AZURE_LOGOUT_BASE_URL = get_setting(['SOCIAL_AUTH_TENANT_B2C_URL', 'TENANT_B2C_URL', 'AZURE_LOGOUT_BASE_URL'],
+                                    default='login.microsoftonline.com')
+AZURE_POLICY = get_setting(['SOCIAL_AUTH_POLICY', 'TENANT_POLICY'])
+AZURE_TENANT_ID = get_setting(['SOCIAL_AUTH_TENANT_ID', 'TENANT_ID'])
+AZURE_RESET_POLICY = get_setting(['SOCIAL_AUTH_PASSWORD_RESET_POLICY', 'PASSWORD_RESET_POLICY'])
 
 UNICEF_EMAIL = os.environ.get('UNICEF_EMAIL', '@unicef.org')
